@@ -13,10 +13,11 @@
 
 import os
 
-from tempest import config  # noqa
+from oslo_config import cfg
+from tempest import config as tempest_config
 from tempest.test_discover import plugins
 
-from ironic_inspector.test.inspector_tempest_plugin import config  # noqa
+from ironic_inspector.test.inspector_tempest_plugin import config
 
 
 class InspectorTempestPlugin(plugins.TempestPlugin):
@@ -28,7 +29,19 @@ class InspectorTempestPlugin(plugins.TempestPlugin):
         return full_test_dir, base_path
 
     def register_opts(self, conf):
-        pass
+        tempest_config.register_opt_group(
+            conf, config.service_available_group,
+            config.ServiceAvailableGroup)
+        tempest_config.register_opt_group(
+            conf, config.baremetal_introspection_group,
+            config.BaremetalIntrospectionGroup)
+        # FIXME(dtantsur): pretend like Neutron does not exist due to random
+        # failures, see https://bugs.launchpad.net/bugs/1621791.
+        cfg.CONF.set_override('neutron', False, 'service_available')
 
     def get_opt_lists(self):
-        pass
+        return [
+            (config.baremetal_introspection_group.name,
+             config.BaremetalIntrospectionGroup),
+            ('service_available', config.ServiceAvailableGroup)
+        ]
